#!/usr/bin/env python

from pyshellspec.include import oifits
import argparse
import numpy as np

def set_error(t3, t3err):
    """
    Adjusts MIRC |T_3| according D. Mourard (priv. comm.)
    @return:
    """
    t3err = 1.0e-5 + 1.1*t3err
    return t3err

def main():
    """
    The main body.
    @return:
    """
    # parse command line argument
    ps = argparse.ArgumentParser()
    ps.add_argument('-f', type=str, required=True, help='Name of the adjusted file.')
    args = ps.parse_args()
    
    # open the fits file
    hdu = oifits.oifits.open(args.f)

    # get closure phase
    t3 = hdu.t3
    
    # get effective wavelengths
    data = dict(eff_wave=[], deltacp=[])
    
    for obs in t3:
        for i in xrange(np.size(obs.t3amp)):
            # take out the observables
            amp = obs.t3amp[i]
            amperr = obs.t3amperr[i]
            
            # set new error
            amperrnew = set_error(amp, amperr)
            
            # assign
            obs.t3amperr[i] = amperrnew
            
            #print amperr, amperrnew

    hdu.save(args.f)
        
if __name__ == '__main__':
    main() 


