#!/usr/bin/gnuplot

# Eq. (1)
P0 = 12.913779
JD0 = 2408247.968
dotP = 3.87265e-6

# JD = JD0 + P0 E + dotP E^2
# dotP E^2 + P0 E + JD0-JD = 0
# a x^2    + b x  + c      = 0
# x = (-b +- sqrt(b^2 - 4ac)) / 2a

x1(a,b,c) = (-b + sqrt(b**2 - 4.*a*c)) / (2.*a)

E(JD) = x1(dotP, P0, JD0-JD)
zero_(E) = E > 0 ? E : E+1.0
phase(JD) = zero_(E(JD)-int(E(JD)))

########################################################################

set term x11

shift = 0.5

set xl "JD - 2400000"
set yl "magnitude [mag]"

set xr [-0.2:1.2]
set yr [:] reverse
#set ytics shift
set grid ytics
set datafile separator ","

p \
  "hvar.U.phot" u (phase($1)):($2+0*shift) w p lt 4 pt 4,\
  "hvar.B.phot" u (phase($1)):($2+1*shift) w p lt 3 pt 3,\
  "hvar.V.phot" u (phase($1)):($2+2*shift) w p lt 2 pt 2,\
  "hvar.R.phot" u (phase($1)):($2+3*shift) w p lt 1 pt 1,\
  "../../data_20170720/photometry/hvar.U.phot" u (phase($1)):($2+0*shift) w p lt 6 pt 4,\
  "../../data_20170720/photometry/hvar.B.phot" u (phase($1)):($2+1*shift) w p lt 5 pt 3,\
  "../../data_20170720/photometry/hvar.V.phot" u (phase($1)):($2+2*shift) w p lt 7 pt 2,\
  "../../data_20170720/photometry/hvar.R.phot" u (phase($1)):($2+3*shift) w p lt 8 pt 1,\

pa -1

set term png small
set out "hvar.png"
rep

q



